# <a name="top"></a>![BrewPi Legacy Remix Logo](https://raw.githubusercontent.com/brewpi-remix/brewpi-www-rmx/master/images/brewpi_logo.png)

Before we proceed, a huge thank you to [Elco Jacobs](https://github.com/elcojacobs), without whom none of this would be possible.

This is [@LBussy](https://github.com/lbussy)'s forks of the original [BrewPi Project](https://github.com/BrewPi).  This project has a new website, please also visit https://www.brewpiremix.com.

This repository contains the PHP web files and other tools for [BrewPi Remix](https://www.brewpiremix.com) which runs on a [Raspberry Pi](https://www.raspberrypi.org/), communicating with an [Arduino](https://www.arduino.cc/en/guide/introduction).  

These [forks](https://en.wikipedia.org/wiki/Fork_(software_development)) are intended for the fans of the *original* BrewPi (called "Legacy" in BrewPi circles).  For current [BrewPi Spark 3](https://www.brewpi.com/) information and support, please continue to use and support [the original project](https://github.com/BrewPi).

# Getting Started

To get started, please head over to the [BrewPi Remix Tools](https://github.com/brewpi-remix/brewpi-tools-rmx/blob/master/README.md) README page, and follow along there.
